AT_AF = "at_af"

base = {
    (0, "at_af"): "núll",
    (1, "et_kk_nf"): "einn",
    (1, "et_kk_þf"): "einn",
    (1, "et_kk_þgf"): "einum",
    (1, "et_kk_ef"): "eins",
    (1, "et_kvk_nf"): "ein",
    (1, "et_kvk_þf"): "eina",
    (1, "et_kvk_þgf"): "einni",
    (1, "et_kvk_ef"): "einnar",
    (1, "et_hk_nf"): "eitt",
    (1, "et_hk_þf"): "eitt",
    (1, "et_hk_þgf"): "einu",
    (1, "et_hk_ef"): "eins",
    (1, "ft_kk_nf"): "einir",
    (1, "ft_kk_þf"): "eina",
    (1, "ft_kk_þgf"): "einum",
    (1, "ft_kk_ef"): "einna",
    (1, "ft_kvk_nf"): "einar",
    (1, "ft_kvk_þf"): "einar",
    (1, "ft_kvk_þgf"): "einum",
    (1, "ft_kvk_ef"): "einna",
    (1, "ft_hk_nf"): "ein",
    (1, "ft_hk_þf"): "ein",
    (1, "ft_hk_þgf"): "einum",
    (1, "ft_hk_ef"): "einna",
    (2, "ft_kk_nf"): "tveir",
    (2, "ft_kk_þf"): "tvo",
    (2, "ft_kk_þgf"): "tveimur/tveim",
    (2, "ft_kk_ef"): "tvegga",
    (2, "ft_kvk_nf"): "tvær",
    (2, "ft_kvk_þf"): "tvær",
    (2, "ft_kvk_þgf"): "tveimur/tveim",
    (2, "ft_kvk_ef"): "tveggja",
    (2, "ft_hk_nf"): "tvö",
    (2, "ft_hk_þf"): "tvö",
    (2, "ft_hk_þgf"): "tveimur/tveim",
    (2, "ft_hk_ef"): "tveggja",
    (3, "ft_kk_nf"): "þrír",
    (3, "ft_kk_þf"): "þrjá",
    (3, "ft_kk_þgf"): "þremur/þrem",
    (3, "ft_kk_ef"): "þriggja",
    (3, "ft_kvk_nf"): "þrjár",
    (3, "ft_kvk_þf"): "þrjár",
    (3, "ft_kvk_þgf"): "þremur/þrem",
    (3, "ft_kvk_ef"): "þriggja",
    (3, "ft_hk_nf"): "þrjú",
    (3, "ft_hk_þf"): "þrjú",
    (3, "ft_hk_þgf"): "þremur/þrem",
    (3, "ft_hk_ef"): "þriggja",
    (4, "ft_kk_nf"): "fjórir",
    (4, "ft_kk_þf"): "fjóra",
    (4, "ft_kk_þgf"): "fjórum",
    (4, "ft_kk_ef"): "fjögurra/fjögra",
    (4, "ft_kvk_nf"): "fjórar",
    (4, "ft_kvk_þf"): "fjórar",
    (4, "ft_kvk_þgf"): "fjórum",
    (4, "ft_kvk_ef"): "fjögurra/fjögra",
    (4, "ft_hk_nf"): "fjögur",
    (4, "ft_hk_þf"): "fjögur",
    (4, "ft_hk_þgf"): "fjórum",
    (4, "ft_hk_ef"): "fjögurra/fjögra",
    (5, "at_af"): "fimm",
    (6, "at_af"): "sex",
    (7, "at_af"): "sjö",
    (8, "at_af"): "átta",
    (9, "at_af"): "níu",
    (10, "at_af"): "tíu",
    (11, "at_af"): "ellefu",
    (12, "at_af"): "tólf",
    (13, "at_af"): "þrettán",
    (14, "at_af"): "fjórtán",
    (15, "at_af"): "fimmtán",
    (16, "at_af"): "sextán",
    (17, "at_af"): "sautján",
    (18, "at_af"): "átján",
    (19, "at_af"): "nítján",
    (20, "at_af"): "tuttugu",
    (30, "at_af"): "þrjátíu",
    (40, "at_af"): "fjörutíu",
    (50, "at_af"): "fimmtíu",
    (60, "at_af"): "sextíu",
    (70, "at_af"): "sjötíu",
    (80, "at_af"): "áttatíu",
    (90, "at_af"): "níutíu",
    (100, "at_af"): "hundrað",
    (1000, "at_af"): "þúsund",
    (1000000, "at_af"): "milljón",
}


declensions = {
    "et": "number",
    "ft": "number",
    "kk": "gender",
    "kvk": "gender",
    "hk": "gender",
    "nf": "case",
    "þf": "case",
    "þgf": "case",
    "ef": "case",
}


def logger():
    import logging

    FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s()] %(message)s"
    logging.basicConfig(level=logging.WARNING, format=FORMAT)
    logger = logging.getLogger(__name__)
    return logger
