from numi.main import spell_out


# Keeping this for quick testing
# for line in spell_out(92):
#     print(line)


# print(spell_out(92))
# for line in spell_out(92, "ft_kvk"):
#     print(line)
# for line in spell_out(92, "kvk"):
#     print(line)
# for line in spell_out(100, "at_af"):
#     print(line)
# for line in spell_out(79, "at_af"):
#     print(line)
# for line in spell_out(13, "at_af"):
#     print(line)
# for line in spell_out(121):
#     print(line)


# for line in spell_out(11):
#     print(line)
# for line in spell_out(111):
#     print(line)
# for line in spell_out(1111):
#     print(line)
# for line in spell_out(9):
#     print(line)
# for line in spell_out(99):
#     print(line)
# for line in spell_out(999):
#     print(line)
# for line in spell_out(9999):
#     print(line)


# print(spell_out(5001, "et_kk_nf"))
# print(spell_out(3124, "ft_kk_nf"))
# print(spell_out(1000, "at_af"))
# print(spell_out(10000))
# print(spell_out(100000))
# print(spell_out(15123))
# print(spell_out(11451))
# print(spell_out(21123))

# 7 print(spell_out(151123))

# print(spell_out(100000))
# print(spell_out(512321))
# print(spell_out(10021, "et_kvk_ef"))
# print(spell_out(10011))
# print(spell_out(10001, "et_kvk_ef"))
# print(spell_out(10221, "et_kvk_ef"))
# print(spell_out(10020))
# print(spell_out(10021, "et_kvk_ef"))
# print(spell_out(10011))
# print(spell_out(10001, "et_kvk_ef"))
# print(spell_out(10221, "et_kvk_ef"))
# for line in spell_out(111101, "et_hk_þf"):
#     print(line)

# print(spell_out(111021, "et_hk_þf"))
# print(spell_out(111001, "et_hk_þf"))
# print(spell_out(111111))
# [
# for line in spell_out(3124, "ft_kk_nf"):
# print(line)
# for line in spell_out(221123, "ft_hk_þgf"):
# print(line)


# print(spell_out("1,1"))
# print(spell_out("2,11"))
# print(spell_out("1,11", "et_kvk_þgf"))
# print(spell_out("1,111", "et_kvk_þgf"))
# print(spell_out("1,1111", "et_kvk_þgf"))


# print(spell_out(975))
# print(spell_out(976))
# print(spell_out(977))
# print(spell_out(978))
# print(spell_out(979))
# print(spell_out(980))
# print(spell_out(92, "ft_kvk_þgf"))
# print(spell_out(995))
# for n in range(1, 1001):
#     for line in spell_out(n):
#         print(line)

# print(spell_out(510000))  # fimmhundruð og tíu þúsund
# print(spell_out(501000))  # fimmhundurð og eitt þúsund
# print(spell_out(503000))  # fimmhundurð og þrjú þúsund
# print(spell_out(212000))  # Tvö hundurð og tólf þúsund
# print(spell_out(914000))  # níuhundurð og fjórtán þúsund
# print(spell_out(18000))  # átján þúsund
# print(spell_out(825000))  # áttahundurð tuttugu og fimm þúsnd
